#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-rename-plugin-2.3.0.0-68dgKX55vw85BiC95gKBe4
key:                  hls-rename-plugin-2.3.0.0-68dgKX55vw85BiC95gKBe4
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  aa5c747ac60e3421fe790dde0889ad38
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.3.0.0-68dgKX55vw85BiC95gKBe4
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-EBdVSHGIn1MFifI9eiYLtn
    ghc-9.6.6 ghc-exactprint-1.7.1.0-1tvX3UuZ7ReIr5GtVrBS0b
    ghcide-2.3.0.0-F3BNAJkMLxZ18LARM9GqQV
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-ZotJ964dbF5LFdeyMGTNG
    hls-plugin-api-2.3.0.0-FlTTTMUPuF0DZZPvKdhYpj
    hls-refactor-plugin-2.3.0.0-I5nmeZbgjN9ZYQRR2zjqG
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    lsp-2.2.0.0-BBA8C8ebAHoAYQmS8hf6TA
    lsp-types-2.0.2.0-54pPdwKIcCc5Qtt9boAlpX
    mod-0.2.1.0-GPylruCz7rMHx33s8ijnig mtl-2.3.1
    syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

